@@ -6,13 +6,7 @@ Bundler.setup
 require "typhoeus"
 require "rspec"
 
-if defined? require_relative
-  require_relative 'support/localhost_server.rb'
-  require_relative 'support/server.rb'
-else
-  require 'support/localhost_server.rb'
-  require 'support/server.rb'
-end
+Dir[File.join(File.dirname(__FILE__), "support/**/*.rb")].each { |f| require f }
 
 RSpec.configure do |config|
   config.order = :rand
@@ -30,5 +24,6 @@ RSpec.configure do |config|
     Typhoeus.on_failure.clear
     Typhoeus::Config.verbose = false
     Typhoeus::Config.block_connection = false
+    Typhoeus::Config.memoize = false
   end
 end
